//***************************************************************************
//      Simple examples how to use ZL.DLL for image visualization
//***************************************************************************

#include "cv.h"  
#include "highgui.h" 
#include <stdio.h>
#include <math.h>
#include <string.h>
#include <windows.h>
#include "zl.h"

CZL ZL;  //DLL information
CZLThread Th;  //Thread
void *V, *Im;  //Viewer and current image

int ThInit(LPVOID Param) //this callback function is called when a thread is initialized
{
	V = ZL.VCreate(VT_ADVANCED,0,0,0,300,300); //create advanced viewer at (0,0) with dimensions 300x300
	return 1;  //viewer is ready to visualize images
}

void ThFin(LPVOID Param)//this callback function is called when a thread is finalized
{
	ZL.VFree(&V); //destroy the viewer
}

//****************************************************************************
// The first example shows 200x200 16-bit one-channel image
//****************************************************************************
void Example()
{
	short val[200*200]; //our image
	short *v;

	int x,xmax = 200*200;

	v = val;
	for (x=0;x<xmax;x++)  //fill the image
		*v++ = (short)x;

	
	CreateZLThread(&Th,&ZL,ThInit,ThFin); //create new wiewer in a new thread
    while (!Th.Ready); //wait while the viewer is being created
	
	Im = ZL.ImCreate("Im",200, 200, 1, DT_SMALLINT, val, TRUE); //create image using our 2D-array

	ZL.ImShow(V,Im); // show image in the viewer

	getchar(); // wait for key

	ZL.ImShow(V,NULL); // show image in the viewer
	ZL.ImFree(V,NULL); //hide image in viewer and destroy it

	TerminateThread(Th.HT,0); //you can use this to destroy the viewer and terminate the thread
}



//****************************************************************************
// Second example shows how to work with IPL an OpenCV.
// The function loads a sequence of images to an IplImage structure and visualizes them.
//****************************************************************************
void OpenCVExample()
{
	IplImage* img = 0;

	char* names[] = { "d://2D_Gel.bmp", "d://pic2.bmp"}; //two our images

    int i;

	CreateZLThread(&Th,&ZL,ThInit,ThFin);    //create new wiewer in a new thread
  
	while (!Th.Ready);//wait while the viewer is being created

	for (i=0; i<2; i++) //for all images
	{
		img = cvvLoadImage( names[i] ); //load next image
		Im = ZL.ImCreate("Im",img->width, img->height, 3, DT_24BITIMAGE, img->imageData, FALSE);
		//create internal image for ZL.DLL
		// NOTE: for simplicity we use only 24-bit color images. Change DT_24BITIMAGE flag
		// according to your data type

		ZL.ImShow(V,Im);// show image in the viewer

		getchar();// wait for a key

		ZL.ImFree(V,Im);//hide internal image in the viewer and destroy it

		cvReleaseImage( &img );//destroy current image
	}
	TerminateThread(Th.HT,0);//you can use this to destroy the viewer and terminate the thread
}

//****************************************************************************
// The third example shows 200x200 16-bit one-channel image in modal viewer
//****************************************************************************

//----
/*
short val[200*200]; //our image

int ModalThInit(LPVOID Param) //this callback function is called when a thread is initialized
{
	Im = ZL.ImCreate("Im",200, 200, 1, DT_SMALLINT, val, TRUE); //create image using our 2D-array
	ZL.ImShowModal(Im,VT_ADVANCED,100,100,300,300); // show image in the viewer (advanced viewer at (100,100) with dimensions 300x300)
	return 1;  //viewer is ready to visualize images
}

void ModalThFin(LPVOID Param)//this callback function is called when a thread is finalized
{
	ZL.ImFree(NULL,Im); //destroy the image
}

void ExampleModal()
{
	short *v;

	int x,xmax = 200*200;

	v = val;
	for (x=0;x<xmax;x++)  //fill the image
		*v++ = (short)x;

	CreateZLThread(&Th,&ZL,ModalThInit,ModalThFin); //create new wiewer in a new thread
    while (!Th.Ready); //wait while the modal viewer shows the image

	TerminateThread(Th.HT,0); //you can use this to destroy the viewer and terminate the thread
}
*/
//---

/**/

//****************************************************************************
// Another version of the third example (without threading stuff)
//****************************************************************************

char val[1000*1000*3]; //our image

void ExampleModal()
{
	char *v;

    CZL ZL;                 
    LPVOID img_look;

	int x,xmax = 1000*1000*3;

	v = val;
	for (x=0;x<xmax;x++)  //fill the image
		*v++ = (char)x;

     LoadZL(&ZL);
	 img_look = ZL.ImCreate("Mate", 1000, 1000, 3,DT_24BITIMAGE , val, FALSE);
	 ZL.ImShowModal(img_look, VT_ADVANCED, 10, 10, 300, 300);
	 ZL.ImFree(NULL, img_look);
	 UnLoadZL(&ZL);

}
/**/

int main()
{

//-----  1st example  ------	
//	OpenCVExample();
//--------------------------

//-----  2nd example  ------	
//	Example();
//--------------------------

//-----  3rd example  ------	
	ExampleModal();
//--------------------------
}

